==> citrus-spring-integration-3.4.0-sources.jar: org/citrusframework/schema/spring_integration/testcase/ObjectFactory.java <==
//
// Diese Datei wurde mit der JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.3.2 generiert 
// Siehe <a href="https://javaee.github.io/jaxb-v2/">https://javaee.github.io/jaxb-v2/</a> 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
// Generiert: 2023.01.28 um 09:09:46 AM CET 
//


package org.citrusframework.schema.spring_integration.testcase;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.citrusframework.schema.spring_integration.testcase package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _Description_QNAME = new QName("http://www.citrusframework.org/schema/spring-integration/testcase", "description");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.citrusframework.schema.spring_integration.testcase
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link PurgeChannel }
     * 
     */
    public PurgeChannel createPurgeChannel() {
        return new PurgeChannel();
    }

    /**
     * Create an instance of {@link PurgeChannel.Channel }
     * 
     */
    public PurgeChannel.Channel createPurgeChannelChannel() {
        return new PurgeChannel.Channel();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.citrusframework.org/schema/spring-integration/testcase", name = "description")
    public JAXBElement<String> createDescription(String value) {
        return new JAXBElement<String>(_Description_QNAME, String.class, null, value);
    }

}

==> citrus-spring-integration-4.1.1-sources.jar: org/citrusframework/schema/spring_integration/testcase/ObjectFactory.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.4 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.schema.spring_integration.testcase;

import javax.xml.namespace.QName;
import jakarta.xml.bind.JAXBElement;
import jakarta.xml.bind.annotation.XmlElementDecl;
import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.citrusframework.schema.spring_integration.testcase package. 
 * <p>An ObjectFactory allows you to programmatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private static final QName _Description_QNAME = new QName("http://www.citrusframework.org/schema/spring-integration/testcase", "description");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.citrusframework.schema.spring_integration.testcase
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link PurgeChannel }
     * 
     * @return
     *     the new instance of {@link PurgeChannel }
     */
    public PurgeChannel createPurgeChannel() {
        return new PurgeChannel();
    }

    /**
     * Create an instance of {@link PurgeChannel.Channel }
     * 
     * @return
     *     the new instance of {@link PurgeChannel.Channel }
     */
    public PurgeChannel.Channel createPurgeChannelChannel() {
        return new PurgeChannel.Channel();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.citrusframework.org/schema/spring-integration/testcase", name = "description")
    public JAXBElement<String> createDescription(String value) {
        return new JAXBElement<>(_Description_QNAME, String.class, null, value);
    }

}
